@@ -27,7 +27,7 @@ class Gaussian:
         self.amp = amp
         self.x_vector = x_vector
 
-    def compute(self, device='cpu'):
+    def compute(self, params, device='cpu'):
         """
 
     Args:
@@ -37,10 +37,10 @@ class Gaussian:
     Returns: out (Tensor): spectra.
 
     """
-        _mean = self.params[:, 0].to(device)
-        _sd = self.params[:, 1].to(device)
-        _amp = self.params[:, 2].to(device)
-        x_vector = torch.Tensor.repeat(self.x_vector, self.params.shape[0]).reshape(self.params.shape[0], -1)
+        _mean = params[:, 0].to(device)
+        _sd = params[:, 1].to(device)
+        _amp = params[:, 2].to(device)
+        x_vector = torch.Tensor.repeat(self.x_vector, params.shape[0]).reshape(params.shape[0], -1)
         x_vector = torch.transpose(x_vector, 0, 1).to(device)
 
         _temp = torch.tensor(math.pi * 2)
